/*

File IKBrowser.h

Release 1.2, 7 June 1994
Copyright (C) 1994 by H. Scott Roy

This code is part of IconKit, a general toolbox for drag-and-drop applications.  IconKit is free for noncommercial use, but costs money for a commercial license.  You should have received a copy of the license agreement with this file.  If not, a copy of the license and the complete source of IconKit can be obtained from the author:

		H. Scott Roy
		2573 Stowe Ct.
		Northbrook, IL  60062-8103
		iconkit@cs.stanford.edu

For your editing convenience, this file is best viewed using an editor that automatically wraps long lines, in a fixed point font at 80 columns, with tabs every 4 spaces.

*/


/* ========================================================================== */


/*

An IKBrowser works like the Workspace file viewer.  Selections are displayed in an icon path, from which they can be dragged or inspected.

*/


#import <appkit/NXBrowser.h>


/* ========================================================================== */


@interface IKBrowser : NXBrowser
{
    id
		iconPath,
		scrollView;
	
	BOOL
		autoSynchronize;
	
	SEL
		scroll;
}


- initFrame: (const NXRect *) frameRect;
- awake;
- iconPath;
- scrollView;
- setIconPath: theIconPath;
- setScrollView: theScrollView;

- sizeTo: (NXCoord) width  : (NXCoord) height;
- sizeCells;
- setAutoSynchronize: (BOOL) flag;
- synchronizePath;
- beginUpdate;
- endUpdate;
- newSelection;
- addColumn;
- takePathFrom: sender;
- resetColumn: (int) n  usingPath: (const char *) path;
- scrolling: sender;
- iconSelected: sender;
- doClick: sender;
- getSelectionInColumn: (int) column;


/*
	-NO NEW DOCUMENTATION-

- (const char *) getInspectorClassName;
- read: (NXTypedStream *) stream;
- write: (NXTypedStream *) stream;

- setLastColumn: (int) n;
- setPath: (const char *) path;
- keyDown: (NXEvent *) theEvent;
- keyUp: (NXEvent *) theEvent;
- selectAll: sender;

*/

@end


/* ========================================================================== */


/*

The browser delegate methods are split up into two types: there's a formal protocol to which delegates must adhere, and several optional methods that will only be called if implemented.

*/


@protocol IKBrowserDelegate

- (int) browser: sender  fillMatrix: matrix  inColumn: (int) column;
- browser: sender  setColumnIcon: cell  for: (int) column;

@end


@interface Object (IKBrowserDelegateOptionalMethods)

- browser: sender  emptyMatrix: matrix  inColumn: (int) column;
- browser: sender  removeColumnIcon: cell  for: (int) column;
- browserWillFinishChange: sender;
- browserDidChange: sender;

@end
