/*

File IKSuitcase.h

Release 1.2, 7 June 1994
Copyright (C) 1994 by H. Scott Roy

This code is part of IconKit, a general toolbox for drag-and-drop applications.  IconKit is free for noncommercial use, but costs money for a commercial license.  You should have received a copy of the license agreement with this file.  If not, a copy of the license and the complete source of IconKit can be obtained from the author:

		H. Scott Roy
		2573 Stowe Ct.
		Northbrook, IL  60062-8103
		iconkit@cs.stanford.edu

For your editing convenience, this file is best viewed using an editor that automatically wraps long lines, in a fixed point font at 80 columns, with tabs every 4 spaces.

*/


/* ========================================================================== */


/*

An IKSuitcase defines the behavior of suitcases in ProjectBuilder and folders in the workspace.  It displays itself as a suitcase and acts as a dragging destination.  Since it inherits from IKList, IKSuitcase conforms to the IKDependency protocol and sends out messages to its users.

*/

#import "IKList.h"

#import <appkit/drag.h>


/* ========================================================================== */


@interface IKSuitcase : IKList <IKEditableObject, IKDragAcceptingObject>
{
	char
		* name,
		* classToHold;
	
	id
		image,
		acceptingDragImage,
		dragging;
	
	int
		draggingSession;
	
	NXDragOperation
		op;
}

+ initialize;

- init: (const char *) theName  count: (unsigned) n;
- init: (const char *) theName;
- free;

- image;
- acceptingDragImage;
- (const char *) name;
- (BOOL) isEditable;
- (BOOL) isDraggable;
- (BOOL) isDragAccepting;
- (const char *) classToHold;
- setName: (const char *) theName;
- setImage: theImage;
- setAcceptingDragImage: theImage;
- setEditable: (BOOL) flag;
- setDragAccepting: (BOOL) flag;
- setClassToHold: (const char * ) class;

- (NXDragOperation)	draggingEntered: (id <NXDraggingInfo>) sender;
- (BOOL) performDragOperation: (id <NXDraggingInfo>) sender;

/*
	-NO NEW DOCUMENTATION-

- (NXImage *) getIBImage;
- (const char *) getInspectorClassName;
- init;
- initCount: (unsigned) n;
- copyFromZone: (NXZone *) zone;
- read: (NXTypedStream *) stream;
- write: (NXTypedStream *) stream;


	// -- dragging methods

- (NXDragOperation)	draggingUpdated: (id <NXDraggingInfo>) sender;
- draggingExited: (id <NXDraggingInfo>) sender;
- (BOOL) prepareForDragOperation: (id <NXDraggingInfo>) sender;
- concludeDragOperation: (id <NXDraggingInfo>) sender;

*/

@end


/* ========================================================================== */


@interface Object (IKSuitcaseAnnouncements)

- didChangeName: sender;
- didChangeImage: sender;
- didChangeAcceptingDragImage: sender;

@end
